@@ -13,6 +13,7 @@ from pydicom.uid import (
     ImplicitVRLittleEndian,
     JPEG2000Lossless,
     JPEGBaseline,
+    UID,
     RLELossless,
 )
 
@@ -157,9 +158,9 @@ def encode_frame(
                         'frames with JPEG Baseline codec.'
                     )
             elif samples_per_pixel == 3:
-                if photometric_interpretation != 'YBR_FULL':
+                if photometric_interpretation != 'YBR_FULL_422':
                     raise ValueError(
-                        'Photometric intpretation must be "YBR_FULL" for '
+                        'Photometric intpretation must be "YBR_FULL_422" for '
                         'encoding of color image frames with '
                         'JPEG Baseline codec.'
                     )
@@ -321,7 +322,7 @@ def decode_frame(
     ds.BitsStored = bits_stored
     ds.HighBit = bits_stored - 1
 
-    if file_meta.TransferSyntaxUID.is_encapsulated:
+    if UID(file_meta.TransferSyntaxUID).is_encapsulated:
         if (transfer_syntax_uid == JPEGBaseline and
                 photometric_interpretation == 'RGB'):
             # RGB color images, which were not transformed into YCbCr color
